# *nonebot-weather*
## 写在前面的话：
这是一个基于wttr.in的天气查询插件，但是由于本人技术有限,在qq使用时无法完美回复`（具体情况为回复错位。）`，假如有足够技术力的朋友，希望能帮我修改。
## 依赖要求：
本项目需求nonebot`2.0`以上，并且安装`aiohttp`。
## 安装与使用：
### pip方法
`pip install nonebot-weather`
### 加载
`nonebot.load_plugin('nonebot-weather')`
### 使用
发送`「天气 城市」`即可查询城市当天与未来三天天气
